local addonName, addon = ...
local PLTrader = addon
local PLT = PLTrader
local DF = _G ["DetailsFramework"]

if (not DF) then
	print ("|cFFFFAA00Personal Loot Trader: framework not found, if you just installed or updated the addon, please restart your client.|r")
	return
end

local L = LibStub ("AceLocale-3.0"):GetLocale ("PersonalLootTrader", true)
if (not L) then
	print ("|cFFFFAA00Personal Loot Trader|r: Reopen your client to finish updating the addon.|r")
	return
end

local config = LibStub("AceConfig-3.0")
local dialog = LibStub("AceConfigDialog-3.0")


local function createconfig()
	local generalOptions
	
	local options = {}
	options.type = "group"
	options.name = "PLT"
	options.args = {}
	
	local function updateExampleRollText()
		local message1 = PLT:GetRollString(200, 150, true)
		local message2 = PLT:GetRollString(100, 50, true)
		generalOptions.args.TraderOptions.args.MSOSMessageOptions.args.ExampleMessage.name = "|cffFFC901Example Messages|r:\n".. message1.."\n"..message2
	end

	
	local function updateMSExampleRollText()
		local message1 = PLT:GetRollString(200, nil, true)
		local message2 = PLT:GetRollString(100, nil, true)
		generalOptions.args.TraderOptions.args.MSMessageOptions.args.ExampleMessage.name = "|cffFFC901Example Messages|r:\n"..message1.."\n"..message2
	end

	
	local function DefaultMessage()
		--PLTVariables.MsgP1 = L["S_ROLL_MSG_P1"]
		PLTrader.db.profile.trader.MSOSMessage = L["S_ROLL_MSG"]
		updateExampleRollText()
		PLT:UpdateExampleText()
	end
	
	local function DefaultMSMessage()
		--PLTVariables.MsgP1 = L["S_ROLL_MSG_P1"]
		PLTrader.db.profile.trader.MSMessage = L["S_MS_ROLL_MSG"]
		updateMSExampleRollText()
		PLT:UpdateExampleText()
	end

	local function DefaultAbbrev()
		PLTrader.db.profile.trader.msabbrev = L["S_MainSpecAbreviation"]
		PLTrader.db.profile.trader.osabbrev = L["S_OffSpecAbreviation"]
		updateExampleRollText()
		PLT:UpdateExampleText()
	end

	
	local function get(info) --don't feel like fixing this to be more dynamic atm
		local ns,opt,opt2 = string.split(".", info.arg)	
		if not opt2 then
			local val = PLTrader.db.profile[ns][opt]

			if type(val) == "table" then
				return unpack(val)
			else
				return val
			end
		else --There are 3 options. This is for the player-spec specific options. I need to change this
			local val = PLTrader.db.profile[ns][opt][opt2]
			if type(val) == "table" then
				return unpack(val)
			else
				--Creates enabled ids if you change them
				PLT.enabledIDs = nil
				return val
			end
		end
	end

	local function set(info, arg1, arg2, arg3, arg4) --don't feel like fixing this atm
		local ns,opt,opt2 = string.split(".", info.arg)
		if arg2 then
			local entry = PLTrader.db.profile[ns][opt]
			entry[1] = arg1
			entry[2] = arg2
			entry[3] = arg3
			entry[4] = arg4
		else --I don't really rememeber why I did this but I don't feel like changing it
			
			if opt2 then --handles the spec change options which have 3 options.
				PLTrader.db.profile[ns][opt][opt2] = arg1
			else
				PLTrader.db.profile[ns][opt] = arg1

				if opt == "MSOSMessage" or opt == "msabbrev" or opt == "osabbrev" then
					updateExampleRollText()
					PLT:UpdateExampleText()
				elseif opt == "MSMessage" then
					updateMSExampleRollText()
					PLT:UpdateExampleText()
				elseif opt == "searchchat" then
					PLT:UpdateChatEvents()
				elseif opt == "receive" then
					PLT:ChangeReceive()
				elseif opt == "length" then
					PLT:UpdateExampleText()
				elseif opt == "usetimer" then
					PLT:UpdateTimerCheck(arg1)
					PLT:UpdateExampleText()
				elseif opt == "scale" then
					PLT:UpdateFramePositions()
				end
			end
		end
	end
	
	local function checkAbbrev(...)
		local _, text = ...
		if string.len(text) < 9 then
			if string.len(text) > 0 then
				return true
			else
				return L["S_ABBREV_ERROR1"]
			end
		else
			return L["S_ABBREV_ERROR2"]
		end
	end
	
	local function checkMSOSMessage(...)
		local _, text = ...
		
		if string.len(text) > 60 then
			return L["S_MSG_TOOLONG"] 
		end
		
		if string.match(text, "%[r1%]") and string.match(text, "%[r2%]") and string.match(text, "%[d1%]") and string.match(text, "%[d2%]") then
			return true
		else
			return L["S_MSG_ERROR1"] 
		end
	
	end
	
	local function checkMSMessage(...)
		local _, text = ...
		
		if string.len(text) > 65 then
			return L["S_MSG_TOOLONG"] 
		end
		
		if string.match(text, "%[r1%]") then
			return true
		else
			return L["S_MSG_ERROR2"] 
		end
	
	end
	
	generalOptions = {
		type = "group",
		order = 1,
		--inline = true,
		name = L["S_ADDON_NAME"] .." - v".. PLT.VERSION.. "                 Author: ".. PLT.AUTHOR,
		childGroups = "tab",
		get = get,
		set = set,
		args = {
			GeneralOptions = {
				order = 1,
				type = "group",
				inline = true,
				name = "General Options",
				childGroups = "tab",
				args = {
					Scale = {
						order = 2,
						type = "range",
						name = L["S_SCALE"],
						desc = L["S_SCALE_DESC"],
						min = .5, max = 1, step = .1,
						arg = "general.scale",
					},
					debugging = {
						order = 3,
						type = "toggle",
						name = L["S_DEBUGGING"],
						desc = L["S_DEBUGGING_DESC"],
						--width = "double",
						arg = "general.debugging",
					
					},
					tooltips = {
						order = 1,
						type = "toggle",
						name = L["S_TOOLTIPS"],
						desc = L["S_TOOLTIPS_DESC"],
						width = "half",
						arg = "general.tooltips",
					
					},
				
				},
			
			},
			
			TraderOptions = {
				order = 1,
				type = "group",
				--inline = true,
				childGroups = "tab",
				name = L["S_TRADER_OPTIONS"],
				args = {
					AutoShow = {
						order = 1,
						type = "toggle",
						name = L["S_AUTO_SHOW"],
						desc = L["S_AUTO_SHOW_DESC"],
						--width = "double",
						arg = "trader.autoshow",
					},
					UseTimer = {
						order = 2,
						type = "toggle",
						name = L["S_USE_TIMER"],
						desc = L["S_USE_TIMER_DESC"],
						width = .75,
						arg = "trader.usetimer",
					},
					Length = {
						order = 3,
						type = "range",
						name = L["S_TIMER_SLIDER"],
						desc = L["S_TIMER_SLIDER_DESC"],
						min = 15, max = 120, step = 5,
						arg = "trader.length",
					},
					AnnounceWinner = {
						order = 4,
						type = "toggle",
						name = L["S_ANNOUNCE_WINNER"],
						desc = L["S_ANNOUNCE_WINNER_DESC"],
						--width = "double",
						arg = "trader.announcewinner",
					},
					WhisperWinner = {
						order = 4,
						type = "toggle",
						name = L["S_WHISPER_WINNER"],
						desc = L["S_WHISPER_WINNER_DESC"],
						--width = "double",
						arg = "trader.whisperwinner",
						width = 2,
					},
					MSOSMessageOptions = {
						order = 8,
						type = "group",
						inline = true,
						name = L["S_MULTI_ROLL_OPTIONS"],
						args = {
							MSAbbrev = {
								order = 9,
								type = "input",
								name = L["S_MS_MSG"],
								desc = L["S_MS_DESC"],
								validate = checkAbbrev,
							--	pattern = "(.-) %%s(.-) %%s(.-)",
								--usage = L["S_MSG_ERROR"],
								width = 1,
								arg = "trader.msabbrev",
							},
							OSAbbrev = {
								order = 10,
								type = "input",
								name = L["S_OS_MSG"],
								desc = L["S_OS_DESC_OPT"],
							--	pattern = "(.-) %%s(.-) %%s(.-)",
								--usage = L["S_MSG_ERROR"],
								validate = checkAbbrev,
								width = 1,
								arg = "trader.osabbrev",
							},
							DefaultAbbev = {
								order = 11,
								type = "execute",
								name = L["S_DEFAULT"],
								desc = L["S_ABBREV_DEFAULT_DESC"],
								width = .5,
								func = DefaultAbbrev,
							},
							ChatLootMessage = {
								order = 12,
								type = "input",
								name = L["S_MSG"],
								desc = L["S_MSG_DESC"],
								--pattern = "(.-) %%s(.-) %%s(.-)",
								--usage = L["S_MSG_ERROR"],
								validate = checkMSOSMessage,
								width = 2,
								arg = "trader.MSOSMessage",
							},
							DefaultMessage = {
								order = 13,
								type = "execute",
								name = L["S_DEFAULT"],
								desc = L["S_DEFAULT_DESC"],
								width = .5,
								func = DefaultMessage,
							},
							ExampleMessage = {
								order = 14,
								type = "description",
								name = "Example Text",
								--fontSize = "medium",
								--width = "double",
								--func = DefaultMessage,
							},
						},
					},
					MSMessageOptions = {
						order = 8,
						type = "group",
						inline = true,
						name = L["S_MS_ONLY_OPTIONS"],
						args = {
							ChatLootMessage = {
								order = 12,
								type = "input",
								name = L["S_MSG"],
								desc = L["S_MSG_MS_DESC"],
								validate = checkMSMessage,
								width = 2,
								arg = "trader.MSMessage",
							},
							DefaultMessage = {
								order = 13,
								type = "execute",
								name = L["S_DEFAULT"],
								desc = L["S_DEFAULT_DESC"],
								width = .5,
								func = DefaultMSMessage,
							},
							ExampleMessage = {
								order = 14,
								type = "description",
								name = "Example Text",
								--fontSize = "medium",
								--width = "double",
								--func = DefaultMSMessage,
							},
						},
					},
				},
			},
			RollerOptions = {
				order = 2,
				type = "group",
				--inline = true,
				childGroups = "tab",
				name = L["S_ROLLER_OPTIONS"],
				args = {
					--Receive = {
					--	order = 1,
					--	type = "toggle",
					--	name = L["S_RECEIVE"],
					--	desc = L["S_RECEIVE_DESC"],
					--	--width = .75,
					--	arg = "roller.receive",
					--},
					SearchChatForRoll = {
						order = 2,
						type = "toggle",
						name = L["S_CHAT_SEARCH"],
						desc = L["S_CHAT_SEARCH_DESC"],
						--width = .75,
						arg = "roller.searchchat",
					},
					SearchChatRollTime = {
						order = 3,
						type = "range",
						name = L["S_CHAT_TIMER_SLIDER"],
						desc = L["S_CHAT_TIMER_SLIDER_DESC"],
						--width = "double",
						min = 10, max = 60, step = 5,
						arg = "roller.searchchattime",
					},
					SpecOptions = {
						order = 4,
						type = "group",
						inline = true,
						--childGroups = "tab",
						name = L["S_SPEC_OPTIONS"],
						args = {},
					},
				},
			},
            RCLCOptions = {
				order = 3,
				type = "group",
				--inline = true,
				childGroups = "tab",
				name = L["S_RCLC_OPTIONS"],
				args = {
                    StopPLT = {
						order = 1,
						type = "toggle",
						name = L["S_RCLC_STOP_PLT"],
						desc = L["S_RCLC_STOP_PLT_DESC"],
						--width = .75,
						arg = "rclc.stopplt",
					},
					Replace = {
						order = 2,
						type = "toggle",
						name = L["S_RCLC_TRADE"],
						desc = L["S_RCLC_TRADE_DESC"],
						--width = .75,
						arg = "rclc.replace",
					},
				},
			},
		},
	}
	
	for ID, _ in pairs(PLT.specIDs) do
		local argStr = "roller."..PLT.name.."."..ID
		
		local _, name = GetSpecializationInfoByID(tonumber(ID))
		generalOptions.args.RollerOptions.args.SpecOptions.args[ID] = {
			order = 5,
			type = "toggle",
			name = name,--L["S_CHAT_SEARCH"],
			desc = L["S_MS_SPEC_DESC"], --L["S_CHAT_SEARCH_DESC"],
			--width = .75,
			arg = argStr,
		}
	end
	
	updateMSExampleRollText()
	updateExampleRollText()
	return generalOptions
end

local function createBlizzOptions()
	local options = createconfig()

	-- General Options
	config:RegisterOptionsTable("Personal Loot Trader", options)
	--local blizzPanel = config:AddToBlizOptions("PLT-General", options.args.general.name, "PLT")
	local blizzPanel = dialog:AddToBlizOptions("Personal Loot Trader", "Personal Loot Trader")
	
	return blizzPanel

end

local addonLoaded = CreateFrame("FRAME") -- Variables
 addonLoaded:RegisterEvent("ADDON_LOADED") --RegisterAddonLoad
 addonLoaded:SetScript("OnEvent",function(self, event, arg1)

 
	if arg1 == "PersonalLootTrader" then
		createBlizzOptions()
	end
	
end)





